In the very last element 100 instead of 800 and the rest are wrong too.
In 1.13 only 1 line is added:
Well I will use my own disassembler in this case, because it is 3 times faster. But I don't really want to write separate code for each template. I think you can parse something simpler with JASON, but you have to check carefully that the data is not substituted.
Allow the use of cookies to log in to the MQL5.com website.
Please enable the necessary setting in your browser, otherwise you will not be able to log in.
You are signed in. Two-factor authentication has been disabled. Set it up again and scan a new QR code, or continue with two-factor authentication disabled.
There is a rewritten fork of the code from this topic (1.12). Have you checked with the original?
PS: I have 1.12 original and heavily corrected. I don't remember where the corrections came from, probably from this branch..
In the very last element 100 instead of 800 and the rest are wrong too.
In 1.13 only 1 line is added:
Well I will use my own disassembler in this case, because it is 3 times faster. But I don't really want to write separate code for each template.
I think you can parse something simpler with JASON, but you have to check carefully that the data is not substituted.
I read the data from the first array, that's why I saw it. After copying, I must not have replaced b with a in the second line.
Now everything is fine.